@@ -11,20 +11,20 @@ use std::ops::{Bound::*, Index, IndexMut, RangeBounds};
 use std::ptr;
 
 ///A Vec-like struct (directly API-compatible where it can be at least as far as function signatures go) implemented with
-///const generics around a static array of fixed "N" capacity.
+///const generics around a static array of fixed `N` capacity.
 pub struct StaticVec<T, const N: usize> {
   data: [MaybeUninit<T>; N],
   length: usize,
 }
 
-///Vaguely similar to a very stripped-down version of std::slice::Iter.
+///Vaguely similar to a very stripped-down version of [std::slice::Iter](std::slice::Iter).
 pub struct StaticVecIteratorConst<'a, T: 'a> {
   current: *const T,
   end: *const T,
   marker: PhantomData<&'a T>,
 }
 
-///Vaguely similar to a very stripped-down version of std::slice::IterMut.
+///Vaguely similar to a very stripped-down version of [std::slice::IterMut](std::slice::IterMut).
 pub struct StaticVecIteratorMut<'a, T: 'a> {
   current: *mut T,
   end: *mut T,
@@ -44,18 +44,25 @@ impl<T, const N: usize> StaticVec<T, {N}> {
 
   ///Returns the current length of the StaticVec.
   ///Just as for a normal Vec, this means the number of elements that
-  ///have been added to it with "push", "insert", e.t.c.
+  ///have been added to it with `push`, `insert`, e.t.c.
   pub fn len(&self) -> usize {
     self.length
   }
 
   ///Returns the total capacity of the StaticVec.
-  ///This is always equivalent to the generic "N" parameter it was declared with,
+  ///This is always equivalent to the generic `N` parameter it was declared with,
   ///which determines the fixed size of the static backing array.
   pub const fn capacity(&self) -> usize {
     N
   }
 
+  ///Directly sets the `length` field of the StaticVec to `new_len`. Useful if you intend
+  ///to write to it solely element-wise, but marked unsafe due to how it creates the potential for reading
+  ///from unitialized memory later on.
+  pub unsafe fn set_len(&mut self, new_len: usize) {
+    self.length = new_len;
+  }
+
   ///Returns true if the current length of the StaticVec is 0.
   pub fn is_empty(&self) -> bool {
     self.length == 0
@@ -86,7 +93,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
     self.data.as_mut_ptr() as *mut T
   }
 
-  ///Returns a constant reference to a slice of the StaticVec's "inhabited" area.
+  ///Returns a constant reference to a slice of the StaticVec's inhabited area.
   pub fn as_slice(&self) -> &[T] {
     unsafe {
       (self.data.get_unchecked(0..self.length) as *const [MaybeUninit<T>] as *const [T])
@@ -95,7 +102,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
     }
   }
 
-  ///Returns a mutable reference to a slice of the StaticVec's "inhabited" area.
+  ///Returns a mutable reference to a slice of the StaticVec's inhabited area.
   pub fn as_mut_slice(&mut self) -> &mut [T] {
     unsafe {
       (self.data.get_unchecked_mut(0..self.length) as *mut [MaybeUninit<T>] as *mut [T])
@@ -104,7 +111,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
     }
   }
 
-  ///Asserts that the current length of the StaticVec is less than "N",
+  ///Asserts that the current length of the StaticVec is less than `N`,
   ///and if so appends a value to the end of it.
   pub fn push(&mut self, value: T) {
     assert!(self.length < N, "No space left!");
@@ -112,8 +119,8 @@ impl<T, const N: usize> StaticVec<T, {N}> {
     self.length += 1;
   }
 
-  ///Removes the value at the last position of the StaticVec and returns it in "Some" if
-  ///the StaticVec has a current length greater than 0, and "None" otherwise.
+  ///Removes the value at the last position of the StaticVec and returns it in `Some` if
+  ///the StaticVec has a current length greater than 0, and returns `None` otherwise.
   pub fn pop(&mut self) -> Option<T> {
     if self.length == 0 {
       None
@@ -124,7 +131,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
   }
 
   ///Appends a value to the end of the StaticVec without asserting that
-  ///its current length is less than "N".
+  ///its current length is less than `N`.
   pub unsafe fn push_unchecked(&mut self, value: T) {
     self.data.get_unchecked_mut(self.length).write(value);
     self.length += 1;
@@ -137,7 +144,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
     self.data.get_unchecked(self.length).read()
   }
 
-  ///Asserts that "index" is less than the current length of the StaticVec,
+  ///Asserts that `index` is less than the current length of the StaticVec,
   ///and if so removes the value at that position and returns it. Any values
   ///that exist in later positions are shifted to the left.
   pub fn remove(&mut self, index: usize) -> T {
@@ -151,8 +158,8 @@ impl<T, const N: usize> StaticVec<T, {N}> {
     }
   }
 
-  ///Asserts that the current length of the StaticVec is less than "N" and that
-  ///"index" is less than the length, and if so inserts "value" at that position.
+  ///Asserts that the current length of the StaticVec is less than `N` and that
+  ///`index` is less than the length, and if so inserts `value` at that position.
   ///Any values that exist in later positions are shifted to the right.
   pub fn insert(&mut self, index: usize, value: T) {
     assert!(
@@ -175,18 +182,18 @@ impl<T, const N: usize> StaticVec<T, {N}> {
     self.length = 0;
   }
 
-  ///Performs an *unstable* in-place sort of the StaticVec's "inhabited" area.
+  ///Performs an unstable in-place sort of the StaticVec's inhabited area.
   pub fn sort(&mut self)
   where T: Ord {
     self.as_mut_slice().sort_unstable();
   }
 
-  ///Reverses the contents of the StaticVec's "inhabited" area in-place.
+  ///Reverses the contents of the StaticVec's inhabited area in-place.
   pub fn reverse(&mut self) {
     self.as_mut_slice().reverse();
   }
 
-  ///Returns a separate, sorted StaticVec of the contents of the StaticVec's "inhabited" area without modifying
+  ///Returns a separate, sorted StaticVec of the contents of the StaticVec's inhabited area without modifying
   ///the original data.
   pub fn sorted(&mut self) -> Self
   where T: Copy + Ord {
@@ -201,7 +208,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
     }
   }
 
-  ///Returns a separate, reversed StaticVec of the contents of the StaticVec's "inhabited" area without modifying
+  ///Returns a separate, reversed StaticVec of the contents of the StaticVec's inhabited area without modifying
   ///the original data.
   pub fn reversed(&mut self) -> Self
   where T: Copy {
@@ -217,7 +224,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
   }
 
   ///Copies and appends all elements in a slice to the StaticVec.
-  ///Unlike the implementation of this function for Vec, no iterator is used,
+  ///Unlike the implementation of this function for [Vec](std::vec::Vec), no iterator is used,
   ///just a single pointer-copy call.
   pub fn extend_from_slice(&mut self, other: &[T])
   where T: Copy {
@@ -265,7 +272,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
     res
   }
 
-  ///Returns a StaticVecIteratorConst over the StaticVec's "inhabited" area.
+  ///Returns a `StaticVecIteratorConst` over the StaticVec's inhabited area.
   pub fn iter<'a>(&'a self) -> StaticVecIteratorConst<'a, T> {
     unsafe {
       if self.length > 0 {
@@ -284,7 +291,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
     }
   }
 
-  ///Returns a StaticVecIteratorMut over the StaticVec's "inhabited" area.
+  ///Returns a `StaticVecIteratorMut` over the StaticVec's inhabited area.
   pub fn iter_mut<'a>(&'a mut self) -> StaticVecIteratorMut<'a, T> {
     unsafe {
       if self.length > 0 {
@@ -305,7 +312,7 @@ impl<T, const N: usize> StaticVec<T, {N}> {
 }
 
 impl<T, const N: usize> Drop for StaticVec<T, {N}> {
-  ///Calls clear() through the StaticVec before dropping it.
+  ///Calls `clear` through the StaticVec before dropping it.
   fn drop(&mut self) {
     self.clear();
   }
@@ -313,7 +320,7 @@ impl<T, const N: usize> Drop for StaticVec<T, {N}> {
 
 impl<T, const N: usize> Index<usize> for StaticVec<T, {N}> {
   type Output = T;
-  ///Asserts that "index" is less than the current length of the StaticVec,
+  ///Asserts that `index` is less than the current length of the StaticVec,
   ///as if so returns the value at that position as a constant reference.
   fn index(&self, index: usize) -> &Self::Output {
     assert!(index < self.length, "Out of range!");
@@ -322,7 +329,7 @@ impl<T, const N: usize> Index<usize> for StaticVec<T, {N}> {
 }
 
 impl<T, const N: usize> IndexMut<usize> for StaticVec<T, {N}> {
-  ///Asserts that "index" is less than the current length of the StaticVec,
+  ///Asserts that `index` is less than the current length of the StaticVec,
   ///as if so returns the value at that position as a mutable reference.
   fn index_mut(&mut self, index: usize) -> &mut Self::Output {
     assert!(index < self.length, "Out of range!");
@@ -332,8 +339,8 @@ impl<T, const N: usize> IndexMut<usize> for StaticVec<T, {N}> {
 
 impl<'a, T: 'a> Iterator for StaticVecIteratorConst<'a, T> {
   type Item = &'a T;
-  ///Returns "Some(self.current.as_ref().unwrap())" if "current" is less than "end",
-  ///and None if it's not.
+  ///Returns `Some(self.current.as_ref().unwrap())` if `current` is less than `end`,
+  ///and `None` if it's not.
   fn next(&mut self) -> Option<Self::Item> {
     if self.current < self.end {
       unsafe {
@@ -349,8 +356,8 @@ impl<'a, T: 'a> Iterator for StaticVecIteratorConst<'a, T> {
 
 impl<'a, T: 'a> Iterator for StaticVecIteratorMut<'a, T> {
   type Item = &'a mut T;
-  ///Returns "Some(self.current.as_mut().unwrap())" if "current" is less than "end",
-  ///and None if it's not.
+  ///Returns `Some(self.current.as_mut().unwrap())` if `current` is less than `end`,
+  ///and `None` if it's not.
   fn next(&mut self) -> Option<Self::Item> {
     if self.current < self.end {
       unsafe {
@@ -367,7 +374,7 @@ impl<'a, T: 'a> Iterator for StaticVecIteratorMut<'a, T> {
 impl<'a, T: 'a, const N: usize> IntoIterator for &'a StaticVec<T, {N}> {
   type IntoIter = StaticVecIteratorConst<'a, T>;
   type Item = <Self::IntoIter as Iterator>::Item;
-  ///Returns a StaticVecIteratorConst over the StaticVec's "inhabited" area.
+  ///Returns a `StaticVecIteratorConst` over the StaticVec's inhabited area.
   fn into_iter(self) -> Self::IntoIter {
     self.iter()
   }
@@ -376,15 +383,15 @@ impl<'a, T: 'a, const N: usize> IntoIterator for &'a StaticVec<T, {N}> {
 impl<'a, T: 'a, const N: usize> IntoIterator for &'a mut StaticVec<T, {N}> {
   type IntoIter = StaticVecIteratorMut<'a, T>;
   type Item = <Self::IntoIter as Iterator>::Item;
-  ///Returns a StaticVecIteratorMut over the StaticVec's "inhabited" area.
+  ///Returns a `StaticVecIteratorMut`` over the StaticVec's inhabited area.
   fn into_iter(self) -> Self::IntoIter {
     self.iter_mut()
   }
 }
 
 impl<T, const N: usize> FromIterator<T> for StaticVec<T, {N}> {
-  ///Attempts to create a new StaticVec instance of the specified capacity from "iter".
-  ///If it has a size greater than the capacity, any contents after that point are ignored.
+  ///Attempts to create a new StaticVec instance of the specified capacity from `iter`.
+  ///If it has a size greater than `N`, any contents after that point are ignored.
   fn from_iter<I: IntoIterator<Item = T>>(iter: I) -> Self {
     let mut res = StaticVec::<T, {N}>::new();
     for value in iter {
